Basics
This check is disabled by default.
Learn how to enable it via .credo.exs.
This check has a base priority of high and works with any version of Elixir.
Explanation
Use Sigra.Audit.log_safe/3 with an explicit scope argument (or nil) instead of the arity-2 shim. Library code MUST make the scope positional argument visible at every call site.
Bad: arity-2 call that passes only (action, opts) Good: arity-3 call that passes (action, scope, opts) Good: arity-3 call that passes (action, nil, opts) for
truly-anonymous pre-auth sites.Check-Specific Parameters
There are no specific parameters for this check.
General Parameters
Like with all checks, general params can be applied.
Parameters can be configured via the .credo.exs config file.