Behaviour for generated email template modules.
The generated MyApp.Auth.Emails module implements this behaviour.
Each callback builds a map with :to, :subject, and :body keys
that can be delivered via Sigra.Delivery.
Security Notification Emails
These templates are called by the library layer inside Auth.authenticate/2
to ensure security notifications are always sent, regardless of how the
developer's generated code calls authenticate.
Summary
Callbacks
Build an API token created notification email.
Build a confirmation email.
Build deletion cancelled confirmation email.
Build deletion finalized notification email.
Build deletion scheduled notification email.
Build email change confirmation email to new address.
Build email change notification email to old address.
Build post-email-change confirmation email to new address.
Build an account lockout notification email.
Build a magic link email.
Build password change notification email.
Build a password reset email.
Build a suspicious login notification email.
Callbacks
Build an API token created notification email.
Build a confirmation email.
Build deletion cancelled confirmation email.
Build deletion finalized notification email.
@callback deletion_scheduled_email( user :: struct(), scheduled_date :: DateTime.t(), cancel_url :: String.t() ) :: map()
Build deletion scheduled notification email.
@callback email_change_confirmation_email( user :: struct(), new_email :: String.t(), url :: String.t() ) :: map()
Build email change confirmation email to new address.
@callback email_change_notification_email( user :: struct(), new_email :: String.t(), cancel_url :: String.t() ) :: map()
Build email change notification email to old address.
Build post-email-change confirmation email to new address.
Build an account lockout notification email.
Build a magic link email.
Build password change notification email.
Build a password reset email.
Build a suspicious login notification email.